#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = 'Ben Lopatin'
__email__ = 'ben@wellfire.co'
__version__ = '0.4.1'


from .client import GeocodioClient  # noqa
from .data import Address, Location, LocationCollection  # noqa

__all__ = [GeocodioClient, Address, Location, LocationCollection]



class GeocodioError(Exception):
    """General but unknown error from Geocodio"""
    pass


class GeocodioAuthError(GeocodioError):
    """HTTP 403 Access Forbidden, likely due to bad API key"""
    pass


class GeocodioDataError(GeocodioError):
    """HTTP 422 Unprocessable Entity, likely poorly formed address"""
    pass


class GeocodioServerError(GeocodioError):
    """HTTP 500 Server Error, remote server failure"""
    pass
